@@ -544,13 +544,9 @@ G_MODULE_EXPORT void do_save_as (GtkWidget *widget, gpointer data)
 
         gw_io_write_file ("w", text);
 
-        GtkWidget *edit_toolbutton;
-        edit_toolbutton = GTK_WIDGET (gtk_builder_get_object (builder, "edit_toolbutton"));
-        gtk_widget_set_sensitive (edit_toolbutton, TRUE);
-
-        GtkAction *edit_menuitem;
-        edit_menuitem = GTK_ACTION (gtk_builder_get_object (builder, "edit_menuitem"));
-        gtk_action_set_sensitive (edit_menuitem, TRUE);
+        GtkAction *edit;
+        edit = GTK_ACTION (gtk_builder_get_object (builder, "file_edit_action"));
+        gtk_action_set_sensitive (edit, TRUE);
     }
 
     gtk_widget_destroy (dialog);
@@ -608,13 +604,9 @@ G_MODULE_EXPORT void do_save (GtkWidget *widget, gpointer data)
 
           gw_io_write_file ("a", text);
 
-          GtkWidget *edit_toolbutton;
-          edit_toolbutton = GTK_WIDGET (gtk_builder_get_object (builder, "edit_toolbutton"));
-          gtk_widget_set_sensitive (edit_toolbutton, TRUE);
-
-          GtkAction *edit_menuitem;
-          edit_menuitem = GTK_ACTION (gtk_builder_get_object (builder, "edit_menuitem"));
-          gtk_action_set_sensitive (edit_menuitem, TRUE);
+          GtkAction *edit;
+          edit = GTK_ACTION (gtk_builder_get_object (builder, "file_edit_action"));
+          gtk_action_set_sensitive (edit, TRUE);
       }
 
       gtk_widget_destroy (dialog);
@@ -1654,7 +1646,10 @@ G_MODULE_EXPORT void do_search_drag_data_recieved (GtkWidget        *widget,
                                                    guint             time,
                                                    gpointer          user_data    )
 {
-    if (strcmp (gtk_buildable_get_name (GTK_BUILDABLE (widget)), "search_entry") == 0)
+    if (widget == NULL) 
+      return;
+    const char *name = gtk_buildable_get_name (GTK_BUILDABLE (widget));
+    if (name == NULL || strcmp (name, "search_entry") == 0)
       return;
 
     GtkWidget* entry = get_widget_by_target (GW_TARGET_ENTRY);
