@@ -319,7 +319,7 @@ int gw_queryline_parse_kanjidict_string (GwQueryLine *ql, const char* string)
     //Make sure it isn't already created
     if (strcmp(ql->string, string) == 0) return TRUE;
 
-    //Make a perminent copy of the query
+    //Make a permanent copy of the query
     strncpy(ql->string, string, MAX_QUERY); 
 
     //Variable preparations
@@ -377,7 +377,7 @@ int gw_queryline_parse_kanjidict_string (GwQueryLine *ql, const char* string)
       ql->grade_total++;
     }
 
-    //Get JLPT 
+    //Get JLPT
     if (regexec(gw_re[GW_RE_QUERY_JLPT], ptr, nmatch, pmatch, 0) == 0)
     {
       start = ptr + pmatch[0].rm_so + 1;
@@ -436,13 +436,21 @@ int gw_queryline_parse_kanjidict_string (GwQueryLine *ql, const char* string)
     {
       strncpy (atom, ptr, next - ptr);
       atom[next - ptr] = '\0';
-      if (regcomp (&(ql->roma_regex                         [GW_QUERYLINE_EXIST] [ql->roma_total]), atom, EFLAGS_EXIST)  != 0) return FALSE;
-      if (regcomp (&(ql->roma_regex                         [GW_QUERYLINE_LOCATE][ql->roma_total]), atom, EFLAGS_LOCATE) != 0) return FALSE;
+      char *high_pattern = g_strdup_printf("\\{%s\\}", atom);
+      char *med_pattern = g_strdup_printf("\\b%s\\b", atom);
+      if (regcomp (&(ql->roma_regex [GW_QUERYLINE_EXIST] [ql->roma_total]), atom, EFLAGS_EXIST)  != 0) return FALSE;
+      if (regcomp (&(ql->roma_regex [GW_QUERYLINE_LOCATE][ql->roma_total]), atom, EFLAGS_LOCATE) != 0) return FALSE;
+      if (regcomp (&(ql->roma_regex [GW_QUERYLINE_HIGH]  [ql->roma_total]), high_pattern, EFLAGS_EXIST)  != 0) return FALSE;
+      if (regcomp (&(ql->roma_regex [GW_QUERYLINE_MED]   [ql->roma_total]), med_pattern, EFLAGS_EXIST)  != 0) return FALSE;
+      if (high_pattern != NULL) g_free(high_pattern);
+      if (med_pattern != NULL) g_free(med_pattern);
+      /*
       if (gw_regex_create_roma_high_regex (&(ql->roma_regex [GW_QUERYLINE_HIGH]  [ql->roma_total]), atom, EFLAGS_EXIST)  != 0) return FALSE;
       if (gw_regex_create_roma_med_regex  (&(ql->roma_regex [GW_QUERYLINE_MED]   [ql->roma_total]), atom, EFLAGS_EXIST)  != 0) return FALSE;
+      */
       ql->roma_total++;
 
-      //Add coversions to search on success
+      //Add conversions to search on success
       if (gw_util_str_roma_to_hira (atom, temp, 300) && want_rk_conv)
       {
         //Hiragana
